==> cscec5b-wzxt-impl-3.0.0-20210319.090523-163-sources.jar: com/ejianc/business/wzxt/bean/ExitApplyEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场申请单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit_apply")
public class ExitApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织ID
    @TableField(value="org_source_id")
    private java.lang.String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private java.lang.Long parentOrgId; // 上级组织ID
    @TableField(value="parent_org_source_id")
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_date")
    private java.util.Date billDate; // 单据日期
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="apply_state")
    private java.lang.Integer applyState; // 关闭状态(1已关闭/0未关闭)
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目ID
    @TableField(value="project_source_id")
    private java.lang.String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同ID
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private java.lang.String supplierSourceId; // 供应商来源ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="exit_date")
    private java.util.Date exitDate; // 预计退场日期
    @TableField(value="exit_desc")
    private java.lang.String exitDesc; // 退场说明    
    @TableField(value="confirm_flag")
    private java.lang.Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 经办人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 经办人名称
    @TableField(value="confirmer_ID")
    private java.lang.Long confirmerId; // 确认人ID
    @TableField(value="confirmer_code")
    private java.lang.Long confirmerCode; // 确认人编码
    @TableField(value="confirmer_name")
    private java.lang.String confirmerName; // 确认人名称
    @TableField(value="confirmt_date")
    private java.util.Date confirmtDate; // 确认日期
    @TableField(value="confirm_desc")
    private java.lang.String confirmDesc; // 确认说明    
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 


    @TableField(exist = false)
    @SubEntity(serviceName="exitApplyDetailService",pidName = "pId")
    private List<ExitApplyDetailEntity> detailList = new ArrayList<>();

    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织ID
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织ID
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 单据日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 关闭状态(1已关闭/0未关闭)
     */
    public java.lang.Integer getApplyState() {
        return applyState;
    }

    /**
     * 关闭状态(1已关闭/0未关闭)
     */
    public void setApplyState(java.lang.Integer applyState) {
        this.applyState = applyState;
    }
    /**
     * 项目ID
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 合同ID
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同ID
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商来源ID
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源ID
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 预计退场日期
     */
    public java.util.Date getExitDate() {
        return exitDate;
    }

    /**
     * 预计退场日期
     */
    public void setExitDate(java.util.Date exitDate) {
        this.exitDate = exitDate;
    }
    /**
     * 退场说明    
     */
    public java.lang.String getExitDesc() {
        return exitDesc;
    }

    /**
     * 退场说明    
     */
    public void setExitDesc(java.lang.String exitDesc) {
        this.exitDesc = exitDesc;
    }
    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public java.lang.Integer getConfirmFlag() {
        return confirmFlag;
    }

    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public void setConfirmFlag(java.lang.Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    /**
     * 经办人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 确认人ID
     */
    public java.lang.Long getConfirmerId() {
        return confirmerId;
    }

    /**
     * 确认人ID
     */
    public void setConfirmerId(java.lang.Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    /**
     * 确认人编码
     */
    public java.lang.Long getConfirmerCode() {
        return confirmerCode;
    }

    /**
     * 确认人编码
     */
    public void setConfirmerCode(java.lang.Long confirmerCode) {
        this.confirmerCode = confirmerCode;
    }
    /**
     * 确认人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 确认人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 确认日期
     */
    public java.util.Date getConfirmtDate() {
        return confirmtDate;
    }

    /**
     * 确认日期
     */
    public void setConfirmtDate(java.util.Date confirmtDate) {
        this.confirmtDate = confirmtDate;
    }
    /**
     * 确认说明    
     */
    public java.lang.String getConfirmDesc() {
        return confirmDesc;
    }

    /**
     * 确认说明    
     */
    public void setConfirmDesc(java.lang.String confirmDesc) {
        this.confirmDesc = confirmDesc;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    
}

==> cscec5b-wzxt-impl-3.0.0-20210320.025604-164-sources.jar: com/ejianc/business/wzxt/bean/ExitApplyEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场申请单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit_apply")
public class ExitApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织ID
    @TableField(value="org_source_id")
    private java.lang.String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private java.lang.Long parentOrgId; // 上级组织ID
    @TableField(value="parent_org_source_id")
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_date")
    private java.util.Date billDate; // 单据日期
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="apply_state")
    private java.lang.Integer applyState; // 关闭状态(1已关闭/0未关闭)
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目ID
    @TableField(value="project_source_id")
    private java.lang.String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="contract_id")
    private java.lang.String contractId; // 合同ID
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private java.lang.String supplierSourceId; // 供应商来源ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="exit_date")
    private java.util.Date exitDate; // 预计退场日期
    @TableField(value="exit_desc")
    private java.lang.String exitDesc; // 退场说明    
    @TableField(value="confirm_flag")
    private java.lang.Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 经办人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 经办人名称
    @TableField(value="confirmer_ID")
    private java.lang.Long confirmerId; // 确认人ID
    @TableField(value="confirmer_code")
    private java.lang.Long confirmerCode; // 确认人编码
    @TableField(value="confirmer_name")
    private java.lang.String confirmerName; // 确认人名称
    @TableField(value="confirm_date")
    private java.util.Date confirmDate; // 确认日期
    @TableField(value="confirm_desc")
    private java.lang.String confirmDesc; // 确认说明    
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 


    @TableField(exist = false)
    @SubEntity(serviceName="exitApplyDetailService",pidName = "pId")
    private List<ExitApplyDetailEntity> exitApplyDetail = new ArrayList<>();

    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织ID
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织ID
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 单据日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 关闭状态(1已关闭/0未关闭)
     */
    public java.lang.Integer getApplyState() {
        return applyState;
    }

    /**
     * 关闭状态(1已关闭/0未关闭)
     */
    public void setApplyState(java.lang.Integer applyState) {
        this.applyState = applyState;
    }
    /**
     * 项目ID
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 合同ID
     */
    public java.lang.String getContractId() {
        return contractId;
    }

    /**
     * 合同ID
     */
    public void setContractId(java.lang.String contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商来源ID
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源ID
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 预计退场日期
     */
    public java.util.Date getExitDate() {
        return exitDate;
    }

    /**
     * 预计退场日期
     */
    public void setExitDate(java.util.Date exitDate) {
        this.exitDate = exitDate;
    }
    /**
     * 退场说明    
     */
    public java.lang.String getExitDesc() {
        return exitDesc;
    }

    /**
     * 退场说明    
     */
    public void setExitDesc(java.lang.String exitDesc) {
        this.exitDesc = exitDesc;
    }
    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public java.lang.Integer getConfirmFlag() {
        return confirmFlag;
    }

    /**
     * 确认状态0-未确认1-已确认2-已拒绝
     */
    public void setConfirmFlag(java.lang.Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    /**
     * 经办人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 确认人ID
     */
    public java.lang.Long getConfirmerId() {
        return confirmerId;
    }

    /**
     * 确认人ID
     */
    public void setConfirmerId(java.lang.Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    /**
     * 确认人编码
     */
    public java.lang.Long getConfirmerCode() {
        return confirmerCode;
    }

    /**
     * 确认人编码
     */
    public void setConfirmerCode(java.lang.Long confirmerCode) {
        this.confirmerCode = confirmerCode;
    }
    /**
     * 确认人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 确认人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 确认日期
     */
    public java.util.Date getConfirmDate() {
        return confirmDate;
    }

    /**
     * 确认日期
     */
    public void setConfirmtDate(java.util.Date confirmtDate) {
        this.confirmDate = confirmDate;
    }
    /**
     * 确认说明    
     */
    public java.lang.String getConfirmDesc() {
        return confirmDesc;
    }

    /**
     * 确认说明    
     */
    public void setConfirmDesc(java.lang.String confirmDesc) {
        this.confirmDesc = confirmDesc;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }


    public List<ExitApplyDetailEntity> getExitApplyDetail() {
        return exitApplyDetail;
    }

    public void setExitApplyDetail(List<ExitApplyDetailEntity> exitApplyDetail) {
        this.exitApplyDetail = exitApplyDetail;
    }
}
